from setuptools import setup

setup(name="gausbin_distribution",
      version="0.2",
      description="Gaussian and Binomial Distribution",
      packages=["gausbin_distributions"],
      author="Victor Oguche",
      author_email = "victoroguche@gmail.com",
      zip_safe=False)